==> auth0_flutter_platform_interface-1.1.0.tar.gz: lib/auth0_flutter_platform_interface.dart <==
export 'src/account.dart';
export 'src/auth/api_exception.dart';
export 'src/auth/auth_login_options.dart';
export 'src/auth/auth_login_with_otp_options.dart';
export 'src/auth/auth_renew_access_token_options.dart';
export 'src/auth/auth_reset_password_options.dart';
export 'src/auth/auth_signup_options.dart';
export 'src/auth/auth_user_info_options.dart';
export 'src/auth0_exception.dart';
export 'src/auth0_flutter_auth_platform.dart';
export 'src/auth0_flutter_web_auth_platform.dart';
export 'src/credentials-manager/credentials_manager_exception.dart';
export 'src/credentials-manager/credentials_manager_platform.dart';
export 'src/credentials-manager/method_channel_credentials_manager.dart';
export 'src/credentials-manager/options/get_credentials_options.dart';
export 'src/credentials-manager/options/has_valid_credentials_options.dart';
export 'src/credentials-manager/options/local_authentication.dart';
export 'src/credentials-manager/options/save_credentials_options.dart';
export 'src/credentials.dart';
export 'src/database_user.dart';
export 'src/method_channel_auth0_flutter_auth.dart';
export 'src/method_channel_auth0_flutter_web_auth.dart';
export 'src/request/request.dart';
export 'src/request/request_options.dart';
export 'src/user_agent.dart';
export 'src/user_profile.dart';
export 'src/web-auth/id_token_validation_config.dart';
export 'src/web-auth/safari_view_controller.dart';
export 'src/web-auth/web_auth_login_options.dart';
export 'src/web-auth/web_auth_logout_options.dart';
export 'src/web-auth/web_authentication_exception.dart';

==> auth0_flutter_platform_interface-1.7.0.tar.gz: lib/auth0_flutter_platform_interface.dart <==
export 'src/account.dart';
export 'src/auth/api_exception.dart';
export 'src/auth/auth_login_options.dart';
export 'src/auth/auth_login_with_otp_options.dart';
export 'src/auth/auth_multifactor_challenge_options.dart';
export 'src/auth/auth_renew_access_token_options.dart';
export 'src/auth/auth_reset_password_options.dart';
export 'src/auth/auth_signup_options.dart';
export 'src/auth/auth_user_info_options.dart';
export 'src/auth/challenge.dart';
export 'src/auth/challenge_type.dart';
export 'src/auth0_exception.dart';
export 'src/auth0_flutter_auth_platform.dart';
export 'src/auth0_flutter_web_auth_platform.dart';
export 'src/auth0_flutter_web_platform.dart';
export 'src/credentials-manager/credentials_manager_exception.dart';
export 'src/credentials-manager/credentials_manager_platform.dart';
export 'src/credentials-manager/method_channel_credentials_manager.dart';
export 'src/credentials-manager/options/get_credentials_options.dart';
export 'src/credentials-manager/options/has_valid_credentials_options.dart';
export 'src/credentials-manager/options/local_authentication.dart';
export 'src/credentials-manager/options/save_credentials_options.dart';
export 'src/credentials.dart';
export 'src/database_user.dart';
export 'src/id_token_validation_config.dart';
export 'src/login_options.dart';
export 'src/method_channel_auth0_flutter_auth.dart';
export 'src/method_channel_auth0_flutter_web_auth.dart';
export 'src/request/request.dart';
export 'src/request/request_options.dart';
export 'src/user_agent.dart';
export 'src/user_profile.dart';
export 'src/web-auth/safari_view_controller.dart';
export 'src/web-auth/web_auth_login_options.dart';
export 'src/web-auth/web_auth_logout_options.dart';
export 'src/web-auth/web_authentication_exception.dart';
export 'src/web/cache_location.dart';
export 'src/web/cache_mode.dart';
export 'src/web/client_options.dart';
export 'src/web/credentials_options.dart';
export 'src/web/logout_options.dart';
export 'src/web/popup_login_options.dart';
export 'src/web/web_exception.dart';
